secret

package module
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 2, 2024 License: MIT Imports: 4 Imported by: 3

README

Secret

A secret management package for Go. Handles secret provisioning and retrieval from different sources.

tag Go Version GoDoc Lint Scan Build Status Go Report Card Contributors License

Usage

go get github.com/zcubbs/secret

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Provide

func Provide(key string, args ...interface{}) (string, error)

Provide returns a secret value for a given key. if the key starts with "file://" then the value is read from the file. if the key starts with "env." then the value is read from the environment variable. if the key starts with "sops." then the value is read from the sops secret using the private key. if the key starts with "zkv." then the value is read from github.com/zcubbs/zkv. if the key starts with "hcv." the value is read from the hashicorp vault. if the key starts with "gcp." then the value is read from the gcp. if the key starts with "aws." then the value is read from the aws. if the key starts with "azure." then the value is read from the azure. if the key starts with "k8s." then the value is read from the k8s.

Types

This section is empty.

Jump to